==> liquidwar-5.3.2.tar.gz: liquidwar-5.3.2/src/move.h <==
/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/********************************************************************/
/* this software is protected by the GPL, see copying.txt           */
/********************************************************************/

/********************************************************************/
/* nom           : move.h                                           */
/* contenu       : deplacement des curseurs                         */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

#ifndef LIQUID_WAR_INCLUDE_MOVE
#define LIQUID_WAR_INCLUDE_MOVE

/*==================================================================*/
/* constantes                                                       */
/*==================================================================*/

#define CURSOR_KEY_UP    1
#define CURSOR_KEY_RIGHT 2
#define CURSOR_KEY_DOWN  4
#define CURSOR_KEY_LEFT  8

/*==================================================================*/
/* fonctions globales                                               */
/*==================================================================*/

void move_all_cursors (void);

#endif

==> liquidwar-5.4.0.tar.gz: liquidwar-5.4.0/src/move.h <==
/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/********************************************************************/
/* this software is protected by the GPL, see copying.txt           */
/********************************************************************/

/********************************************************************/
/* nom           : move.h                                           */
/* contenu       : deplacement des curseurs                         */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

#ifndef LIQUID_WAR_INCLUDE_MOVE
#define LIQUID_WAR_INCLUDE_MOVE

/*==================================================================*/
/* constantes                                                       */
/*==================================================================*/

/*
 * these constants are combined with a logic "or" to produce a
 * "key state" value which is used to move the cursors.
 */
#define CURSOR_KEY_UP    1
#define CURSOR_KEY_RIGHT 2
#define CURSOR_KEY_DOWN  4
#define CURSOR_KEY_LEFT  8

/*==================================================================*/
/* fonctions globales                                               */
/*==================================================================*/

void move_all_cursors (void);

#endif
